from datetime import datetime
from .utils import attrdict


class SPB:
    def __str__(self) -> str:
        return f"<{self.__class__.__name__}: {self.__dict__}>"

    def __repr__(self) -> str:
        return self.__str__()


class Blacklist(SPB):
    def __init__(self, success: bool, response_code: int, results=dict, **kwargs):
        self.success = success
        self.response_code = response_code
        try:
            self.private_telegram_id = results["private_telegram_id"]
            self.entity_type = results["entity_type"]
            self.attributes = attrdict(results["attributes"])
            self.language_prediction = attrdict(results["language_prediction"])
            self.spam_prediction = attrdict(results["spam_prediction"])
            self.last_updated = datetime.fromtimestamp(results["last_updated"])
        except TypeError:
            pass



import requests

from .errors import UnknownError
from .types import Blacklist

from json import JSONDecodeError
from typing import Union


class SPBClient:
    def __init__(
        self, *, host: str = "https://api.intellivoid.net/spamprotection/v1/lookup"
    ) -> None:
        self._host = host

    def do_request(self, user_id: str, method: str = "get"):
        request = requests.get(f"{self._host}?query={user_id}")
        try:
            return request.json(), request
        except JSONDecodeError:
            return request.text(), request

    def raw_output(self, user_id: Union[int, str]) -> Union[Blacklist, bool]:
        try:
            data, _ = self.do_request(user_id)
            return data
        except UnknownError:
            return False

    def check_blacklist(self, user_id: Union[int, str]) -> Union[Blacklist, bool]:
        try:
            data, _ = self.do_request(user_id)
            return Blacklist(**data)
        except UnknownError:
            return False



from spamprotection import SPBClient
from spamprotection.types import Blacklist
import asyncio

# initializing the client
client = SPBClient()


async def main():
    # calling for status
    user = input("Enter a Username or UserID to check Spam Prediction on SPB: ")
    status = await client.check_blacklist(user)
    # check if status got a successful response
    if status.success:
        print((await text_parser(status)))
    else:
        print("Polish Cow did not Approve this!")


async def text_parser(status: Blacklist):
    text = "Private TelegramID: {}\n".format(status.private_telegram_id)
    text += "Entity Type: {}\n".format(status.entity_type)
    if status.attributes.is_blacklisted:
        text += "Blacklist Flag: {}\n".format(status.attributes.blacklist_flag)
        text += "Blacklist Reason: {}\n".format(status.attributes.blacklist_reason)
    text += "Original PrivateID: {}\n".format(status.attributes.original_private_id)
    if status.attributes.is_potential_spammer:
        text += "This user is a Spammer\n"
    if status.attributes.is_operator:
        text += "This user is an Operator\n"
    if status.attributes.is_agent:
        text += "This user is an Agent\n"
    if status.attributes.is_whitelisted:
        text += "This user is Whitelisted\n"
    if status.attributes.intellivoid_accounts_verified:
        text += "This user is an Intellivoid Verified Account\n"
    if status.attributes.is_official:
        text += "This is an Official Account\n"
    text += "Language: {}\n".format(status.language_prediction.language)
    text += "Language Probability: {}\n".format(status.language_prediction.probability)
    text += "Ham Prediction: {}\n".format(status.spam_prediction.ham_prediction)
    text += "Spam Prediction: {}\n".format(status.spam_prediction.spam_prediction)
    text += "Last Updated On: {}\n".format(status.last_updated)
    return text


if __name__ == "__main__":
    loop = asyncio.get_event_loop()
    loop.run_until_complete(main())
    loop.close()



#!/usr/bin/env python
import setuptools
from spamprotection import __version__

with open("README.md", "r") as fh:
    long_description = fh.read()

with open("requirements.txt") as f:
    dependencies = [_.strip() for _ in f]


setuptools.setup(
    name="Intellivoid SPB",
    version=__version__,
    description="Unofficial SPB API Wrapper",
    long_description=long_description,
    long_description_content_type="text/markdown",
    license="GNU Lesser General Public License v3 (LGPLv3)",
    author="Pokurt",
    author_email="poki@pokurt.me",
    url="https://github.com/pokurt/intellivoid-spam-protection",
    packages=setuptools.find_packages(),
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Programming Language :: Python :: 3.8",
    ],
    install_requires=dependencies,
    python_requires=">=3.6",
)
